# Therapist
Work out your commitment issues. A smart pre-commit hook for git.

![PyPI](https://img.shields.io/pypi/v/therapist.svg)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/therapist.svg)

[![Build Status](https://travis-ci.org/rehandalal/therapist.svg?branch=master)](https://travis-ci.org/rehandalal/therapist)
[![Documentation Status](https://readthedocs.org/projects/therapist/badge/?version=latest)](http://therapist.readthedocs.io/en/latest/?badge=latest)
[![Requirements Status](https://requires.io/github/rehandalal/therapist/requirements.svg?branch=master)](https://requires.io/github/rehandalal/therapist/requirements/?branch=master)


## Documentation

Full documentation for this tool is available at: 
http://therapist.readthedocs.io/
